==> assemblyline_client-4.2.0.dev0-py2.py3-none-any.whl: assemblyline_client/v4_client/module/search/histogram.py <==
from assemblyline_client.v4_client.common.utils import SEARCHABLE, ClientError, api_path


class Histogram(object):
    def __init__(self, connection):
        self._connection = connection

    def _do_histogram(self, index, field, **kwargs):
        if index not in SEARCHABLE:
            raise ClientError("Index %s is not searchable" % index, 400)

        filters = kwargs.pop('filters', None)
        if filters is not None:
            if isinstance(filters, str):
                filters = [filters]

            filters = [('filters', fq) for fq in filters]

        kwargs = {k: v for k, v in kwargs.items() if v is not None and k != 'filters'}
        if filters is not None:
            kwargs['params_tuples'] = filters
        path = api_path('search', 'histogram', index, field, **kwargs)
        return self._connection.get(path)

    def alert(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the alert index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('alert', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

    def file(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the file index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('file', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

    def result(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the result index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('result', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

    def safelist(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the safelist index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('safelist', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

    def signature(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the signature index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('signature', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

    def submission(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the submission index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('submission', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

    def workflow(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None):
        """\
Create an histogram of data from a given field in the workflow index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)

Returns all results.
"""
        return self._do_histogram('workflow', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap)

==> assemblyline_client-4.9.5-py2.py3-none-any.whl: assemblyline_client/v4_client/module/search/histogram.py <==
from assemblyline_client.v4_client.common.utils import SEARCHABLE, ClientError, api_path


class Histogram(object):
    def __init__(self, connection):
        self._connection = connection

    def _do_histogram(self, index, field, **kwargs):
        if index not in SEARCHABLE:
            raise ClientError("Index %s is not searchable" % index, 400)

        filters = kwargs.pop('filters', None)
        if filters is not None:
            if isinstance(filters, str):
                filters = [filters]

            filters = [('filters', fq) for fq in filters]

        kwargs = {k: v for k, v in kwargs.items() if v is not None and k != 'filters'}
        if filters is not None:
            kwargs['params_tuples'] = filters
        path = api_path('search', 'histogram', index, field, **kwargs)
        return self._connection.get(path)

    def alert(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the alert index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('alert', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def badlist(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the badlist index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('badlist', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def file(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the file index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('file', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def result(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the result index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('result', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def safelist(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the safelist index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('safelist', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def signature(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the signature index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('signature', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def submission(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the submission index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('submission', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)

    def workflow(self, field, query=None, mincount=None, filters=None, start=None, end=None, gap=None, timeout=None):
        """\
Create an histogram of data from a given field in the workflow index where the frequency
of the data is split between a given gap size.

Required:
field   : field to create the histograms with (only work on date or number fields)

Optional:
query    : Initial query to filter the data (default: 'id:*')
filters  : Additional lucene queries used to filter the data (list of strings)
mincount : Minimum amount of hits for the value to be returned
start    : Beginning of the histogram range (Default: now-1d or 0)
end      : End of the histogram range (Default: now or 1000)
gap      : Interval in between each histogram points (Default: 1h or 100)
timeout  : Maximum execution time in milliseconds (integer)

Returns all results.
"""
        return self._do_histogram('workflow', field, query=query, mincount=mincount, filters=filters,
                                  start=start, end=end, gap=gap, timeout=timeout)
